(* ****************************************************************** *)
(* *****                                                        ***** *)
(* *****  FeynRules model file: Simplified DM models with LQ    ***** *)
(* *****                                                        ***** *)
(* *****  Author: Benjamin Fuks                                 ***** *)
(* *****                                                        ***** *)
(* ****************************************************************** *)

(* ************************** *)
(* *****  Information   ***** *)
(* ************************** *)
M$ModelName = "LQDM";

M$Information = { Authors->{"Benjamin Fuks"}, Emails->{"fuks@lpthe.jussieu.fr"},
                  Institutions->{"LPTHE / Sorbonne U."},
                  Date->"23.06.19", Version->"1.0",
                  URLs->""};

(* ************************** *)
(* *****  Change  log   ***** *)
(* ************************** *)

(* 2019.06.23 v1.0 - First version *)

(* ************************** *)
(* *****     Fields     ***** *)
(* ************************** *)
M$ClassesDescription = {
  (* Dark sector *)
  F[100] == { ClassName -> chi1, SelfConjugate->False, Indices->{Index[Colour]},
              QuantumNumbers -> {Y->-1/3, Q->-1/3, LeptonNumber->1},
              Mass -> {Mchi1, 500.}, Width -> {Wchi1,5.}, PDG -> 5000521},
  F[101] == { ClassName -> chi0, SelfConjugate -> True,
              Mass -> {Mchi0, 50.},  Width -> 0, PDG -> 5000522},

  (* Leptoquarks *)
  S[200] == { ClassName -> LQ, SelfConjugate->False, Indices->{Index[Colour]},
              QuantumNumbers -> {Y->-1/3, Q->-1/3, LeptonNumber->1},
              Mass  -> {MLQ, 1000.}, Width -> {WLQ, 10.}, PDG -> 42}

};

(* ************************** *)
(* *****   Parameters   ***** *)
(* ************************** *)
M$Parameters = {

 lamL == { ParameterType -> External, ComplexParameter -> False,
            TeX -> Subscript[\[Lambda],L], BlockName -> LQLAML,
            Indices -> {Index[Generation], Index[Generation]},
            InteractionOrder -> {QED,1},
            Value -> {
             lamL[1,1] -> 0.0 , lamL[1,2] -> 0.0 , lamL[1,3] -> 0.0 ,
             lamL[2,1] -> 0.0 , lamL[2,2] -> 0.0 , lamL[2,3] -> 0.0 ,
             lamL[3,1] -> 0.12, lamL[3,2] -> 0.12, lamL[3,3] -> 0.12}},
 lamR == { ParameterType -> External, ComplexParameter -> False,
            TeX -> Subscript[\[Lambda],R], BlockName -> LQLAMR,
            Indices -> {Index[Generation], Index[Generation]},
            InteractionOrder -> {QED,1},
            Value -> {
             lamR[1,1] -> 0.0, lamR[1,2] -> 0.0, lamR[1,3] -> 0.0 ,
             lamR[2,1] -> 0.0, lamR[2,2] -> 0.0, lamR[2,3] -> 0.11,
             lamR[3,1] -> 0.0, lamR[3,2] -> 0.0, lamR[3,3] -> 0.0}},
 yDM  == { ParameterType -> External, ComplexParameter -> False,
            TeX -> Subscript[y,DM], BlockName -> DMINPUTS,
            InteractionOrder -> {QED,1},
            Value -> 0.2},

  UEps== { ParameterType->Internal, ComplexParameter->False,
            Indices -> {Index[SU2D], Index[SU2D]},
            Definitions -> { UEps[1,1]->0, UEps[1,2]->-1, UEps[2,1]-> 1, UEps[2,2]->0 },
            Description -> "Epsilon in SU2 space (with upper indices)", TeX->Subscript[\[Epsilon],u]}
};

(* ************************** *)
(* *****   Lagrangian   ***** *)
(* ************************** *)

Lkin := I chi1bar.Ga[mu].DC[chi1,mu] - Mchi1 chi1bar.chi1 \
      + I/2 chi0bar.Ga[mu].DC[chi0,mu] - 1/2 Mchi0 chi0bar.chi0 \
      + DC[LQbar[cc],mu] DC[LQ[cc],mu] - MLQ^2 LQbar[cc] LQ[cc];

Lint := lamR[ii, jj] CC[uRbar][sp, ii, cc].lR[sp, jj] LQbar[cc] \
      + UEps[kk,ll] lamL[ii,jj] CC[QLbar][sp,kk,ii,cc].LL[sp,ll,jj] LQbar[cc] \
      + yDM chi1bar[sp, cc].chi0[sp] LQ[cc];

LNP := Lkin+Lint+HC[Lint];
